DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_verifyVentaSync`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_verifyVentaSync`(
    p_id_venta	INT
)
    COMMENT 'Recupera el sig. corte de caja pendiente de sincronizar'
BEGIN
    SELECT m.id_movimiento
    FROM tbl_movimientos AS m
    WHERE m.id_movimiento = p_id_venta
	AND m.id_tipo_movimiento = 1
        AND m.pagado >= total
        AND m.fecha_cancelado IS NULL
        AND m.consolidado IS NULL;
END$$

DELIMITER ;



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_producto_x_codigo`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_producto_x_codigo`(
	p_codigo VARCHAR(30)
)
    COMMENT 'Búsqueda de Producto por Código'
BEGIN
    IF TRIM(BOTH FROM p_codigo) <> '' THEN
	SELECT 1 AS cantidad,
		prd.modelo,
		prd.nombre AS descripcion,
		prd.precio_venta AS precio_unitario,
		prd.precio_venta,
		0.00 AS subtotal,
		0.00 AS iva,
		0.00 AS total,
		prd.tasa_iva,
		prd.iva_incluido,
		prd.imagen,
		prd.id_producto,
		prd.clave
	FROM cat_productos_servicios AS prd
	JOIN cat_configuracion AS cfg
	WHERE BINARY prd.clave = p_codigo
	        OR prd.codigo_proveedor = p_codigo
		OR BINARY LEFT(prd.clave, cfg.group_len) = p_codigo
		OR BINARY prd.modelo = p_codigo;
    END IF;
END$$

DELIMITER ;



DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_syncCortes`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_syncCortes`(
    p_id_corte	INT
)
    COMMENT 'Recupera el sig. corte de caja pendiente de sincronizar'
BEGIN
    IF ISNULL(p_id_corte) THEN
        SELECT *
        FROM tbl_cortes_caja AS cc
        WHERE cc.consolidado IS NULL
        ORDER BY cc.id_corte
        LIMIT 1;
    ELSE
        SELECT *
        FROM tbl_cortes_caja AS cc
        WHERE id_corte = p_id_corte
            AND cc.consolidado IS NULL;
    END IF;
END$$

DELIMITER ;



